from django.conf.urls.defaults import patterns, url

urlpatterns = patterns(
    'event.views',
    url(r'^list/$', 'object_list', name='event_entryitem_list'),
    url(r'^(?P<slug>[\w-]+)/$', 'object_detail', name='event_object_detail'),
)



from django.core.urlresolvers import reverse

from cal.models import EntryItem
from event.models import Event
from panya.generic.views import GenericObjectList, GenericObjectDetail
from panya.models import ModelBase
from panya.view_modifiers import DateFieldIntervalViewModifier

class ObjectList(GenericObjectList):
    def get_extra_context(self, *args, **kwargs):
        return {'title': 'Events'}
    
    def get_view_modifier(self, request, *args, **kwargs):
        return DateFieldIntervalViewModifier(request=request, field_name='start')

    def get_paginate_by(self, *args, **kwargs):
        return 7
    
    def get_queryset(self, *args, **kwargs):
        return EntryItem.permitted.by_model(Event).order_by('start')
    
    def get_template_name(self, *args, **kwargs):
        return 'event/event_entryitem_list.html'

object_list = ObjectList()

class ObjectDetail(GenericObjectDetail):
    def get_extra_context(self, *args, **kwargs):
        return {'title': 'Events'}
    
    def get_view_modifier(self, request, *args, **kwargs):
        return DateFieldIntervalViewModifier(request=request, field_name='start', base_url=reverse("event_entryitem_list"), ignore_defaults=True)

    def get_queryset(self, *args, **kwargs):
        return Event.permitted.all()
        
object_detail = ObjectDetail()



from django import template

register = template.Library()

@register.inclusion_tag('event/inclusion_tags/event_entryitem_listing.html')
def event_entryitem_listing(object_list):
    return {'object_list': object_list}

@register.inclusion_tag('event/inclusion_tags/event_detail.html')
def event_detail(obj):
    return {'object': obj}



from django.contrib import admin

from panya.admin import ModelBaseAdmin
from event.models import Event, Location, Venue

admin.site.register(Event, ModelBaseAdmin)
admin.site.register(Location)
admin.site.register(Venue)



from django.db import models
from django.core.urlresolvers import reverse

from ckeditor.fields import RichTextField
from panya.models import ModelBase

PROVINCES = (
    ('Eastern Cape', 'Eastern Cape'),
    ('Free State', 'Free State'),
    ('Gauteng', 'Gauteng'),
    ('KwaZulu-Natal', 'KwaZulu-Natal'),
    ('Limpopo', 'Limpopo'),
    ('Mpumalanga', 'Mpumalanga'),
    ('Northern Cape', 'Northern Cape'),
    ('North-West', 'North-West'),
    ('Western Cape', 'Western Cape'),
)
    
class Location(models.Model):
    city = models.CharField(max_length=255, help_text='Name of the city.')
    province = models.CharField(
        choices=PROVINCES,
        max_length=255,
        help_text='Name of the province.'
    )

    def __unicode__(self):
        return "%s, %s" % (self.city, self.province)

class Venue(models.Model):
    name = models.CharField(max_length=255, help_text='A short descriptive name.')
    address = models.CharField(max_length=512, help_text='Physical venue address.')
    location = models.ForeignKey(
        Location,
        blank=True,
        null=True,
        help_text='Location of the venue.'
    )

    def __unicode__(self):
        return self.name

class Event(ModelBase):
    venue = models.ForeignKey(
        Venue,
        help_text='Venue where the event will take place.'
    )
    content = RichTextField(help_text='Full article detailing this event.')

    def get_absolute_url(self):
        return reverse('event_object_detail', kwargs={'slug': self.slug})




import random
from datetime import datetime, timedelta

from django.conf import settings

from generate import IMAGES
from generate.json_loader import load_json
from event.models import PROVINCES

EVENT_COUNT = 20

def generate():
    objects = []
    
    # create event, venue and location objects
    for i in range(1, EVENT_COUNT + 1):
        objects.append({
            "model": "event.Event",
            "fields": {
                "title": "Event %s Title" % i,
                "description": "Event %s description with some added text to verify truncates where needed." % i,
                "content": "Event %s Content" % i,
                "state": "published",
                "image": random.sample(IMAGES, 1)[0],
                "sites": {
                    "model": "sites.Site",
                    "fields": { 
                        "name": "example.com",
                    }
                },
                "venue": {
                    "model": "event.Venue",
                    "fields": { 
                        "name": "Venue %s Title" % i,
                        "address": "Venue %s Address" % i,
                        "location": {
                            "model": "event.Location",
                            "fields": {
                                "city": "City %s Title" % i,
                                "province": "%s" % random.choice(PROVINCES)[0],
                            }
                        },
                    }
                },
            },
        })
    
    # create some entries for events
    for i in range(0, EVENT_COUNT + 1):
        start_date = datetime.now() + timedelta(days=random.randint(1, 30))
        end_date = start_date + timedelta(hours=random.randint(1, 48))
        objects.append({
            "model": "cal.Entry",
            "fields": {
                "start": str(start_date),
                "end": str(end_date),
                "content": {
                    "model": "event.Event",
                    "fields": {
                        "title": "Event %s Title" % random.randint(1, EVENT_COUNT),
                    }
                },
                "calendars": {
                    "model": "cal.Calendar",
                    "fields": {
                        "title": "Calendar 2 Title",
                        "state": "published",
                        "image": random.sample(IMAGES, 1)[0],
                        "sites": {
                            "model": "sites.Site",
                            "fields": { 
                                "name": "example.com"
                            },
                        },
                    },
                },
            },
        })
    
    load_json(objects)
